import logging
logger = logging.getLogger(__name__)
logger.info("Loaded " + __name__)

import os
import operator

from eazyserver.core.utils import list_routes, get_app_config_as_dict, toJSON

from flask import Blueprint, jsonify, Response, make_response, request, \
    current_app as app

config_bp = Blueprint('eazy_config_routes', __name__)

@config_bp.route('/config', methods=['GET'])
def config():
    response = get_app_config_as_dict()
    return Response(toJSON(response), 200,
        mimetype='application/json')

@config_bp.route('/info', methods=['GET'])
def get_info():
    response = {
        "name": app.config["NAME"],
        "description": app.config["DESCRIPTION"],
        "version": app.config["VERSION"],
        "build": {
            "href": os.environ.get('CI_BUILD_LINK', '-')
        },
        "repo": {
            "name": os.environ.get('CI_REPO_NAME', '-'),
            "href": os.environ.get('CI_REPO_LINK', '-')
        },
        "commit": {
            "href": os.environ.get('CI_COMMIT_LINK', '-'),
            "author": os.environ.get('CI_COMMIT_AUTHOR_EMAIL', '-'),
        }
    }
    return jsonify(response)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages
import os
import glob

with open('VERSION') as version_file:
    version = version_file.read().strip()

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

with open('AUTHORS.rst') as authors_file:
    authors = authors_file.read()

with open('CONTRIBUTING.rst') as contributing_file:
    contributing = contributing_file.read()

requirements = ['Click>=6.0', ]
with open('requirements_dev.txt') as f:
    requirements = f.read().splitlines()

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Ashutosh Mishra",
    author_email='ashutoshdtu@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="A simple python web framework for creating RESTful and JSON-RPC services",
    entry_points={
        'console_scripts': [
            'eazyserver=eazyserver.cli:cli',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='eazyserver',
    name='eazyserver',
    packages=find_packages("src", include=['eazyserver']),
    package_dir={"": "src"},
    py_modules=[os.path.splitext(os.path.basename(i))[0] for i in glob.glob("src/*.py")],
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/ashutoshdtu/eazyserver',
    version=version,
    zip_safe=False,
)
